==> qt2-2.1.tgz: include/X11/qt2/qt.h <==
/****************************************************************************
**
** Qt GUI Toolkit
**
** This header file efficiently includes all Qt GUI Toolkit functionality.
**
** Generated : Mon Jul 31 17:45:33 CEST 2000

**
** Copyright (C) 1995-2000 Trolltech AS.  All rights reserved.
**
** This file is part of the kernel module of the Qt GUI Toolkit.
**
** This file may be distributed under the terms of the Q Public License
** as defined by Trolltech AS of Norway and appearing in the file
** LICENSE.QPL included in the packaging of this file.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
** licenses may use this file in accordance with the Qt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
**   information about Qt Commercial License Agreements.
** See http://www.trolltech.com/qpl/ for QPL licensing information.
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#ifndef QT_H
#define QT_H
#include <qglobal.h>
#include <qfeatures.h>
#include <qshared.h>
#include "qgarray.h"
#include "qcollection.h"
#include "qglist.h"
#include <qarray.h>
#include "qcstring.h"
#include <qstring.h>
#include "qnamespace.h"
#include "qbitarray.h"
#include "qobjectdefs.h"
#include "qwindowdefs.h"
#include "qiodevice.h"
#include "qcolor.h"
#include <qfont.h>
#include "qgdict.h"
#include <qlist.h>
#include <qpoint.h>
#include "qdatastream.h"
#include "qregexp.h"
#include "qvaluelist.h"
#include "qbrush.h"
#include "qfontinfo.h"
#include <qmime.h>
#include <qsize.h>
#include <qrect.h>
#include "qregion.h"
#include <qstringlist.h>
#include "qsizepolicy.h"
#include "qpalette.h"
#include "qdatetime.h"
#include "qrangecontrol.h"
#include "qevent.h"
#include <qdict.h>
#include <stdio.h>
#include "qobject.h"
#include "qstrlist.h"
#include <qpen.h>
#include <qdropsite.h>
#include "qjpunicode.h"
#include "qtextcodec.h"
#include "qfontmetrics.h"
#include "qstyle.h"
#include "qfile.h"
#include "qfileinfo.h"
#include "qcursor.h"
#include "qpaintdevice.h"
#include <qwidget.h>
#include <qfontdatabase.h>
#include "qdialog.h"
#include <qcolordialog.h>
#include "qframe.h"
#include "qgroupbox.h"
#include <qeuckrcodec.h>
#include <qgbkcodec.h>
#include "qgcache.h"
#include "qintdict.h"
#include <qgif.h>
#include <qcache.h>
#include "qasciidict.h"
#include <qgrid.h>
#include "qbuttongroup.h"
#include <qguardedptr.h>
#include "qgvector.h"
#include "qhbox.h"
#include <qhbuttongroup.h>
#include <qpixmap.h>
#include <qhgroupbox.h>
#include <qiconset.h>
#include "qpointarray.h"
#include <qimage.h>
#include <qlineedit.h>
#include <qintcache.h>
#include "qtranslator.h"
#include "qbuffer.h"
#include <qjiscodec.h>
#include <qeucjpcodec.h>
#include <qkeycode.h>
#include <qkoi8codec.h>
#include "qlabel.h"
#include <qfontdialog.h>
#include <qlcdnumber.h>
#include "qtimer.h"
#include <qptrdict.h>
#include "qwmatrix.h"
#include "qpainter.h"
#include <qqueue.h>
#include "qmainwindow.h"
#include <qmap.h>
#include "qmenudata.h"
#include "qpopupmenu.h"
#include <qmessagebox.h>
#include "qconnection.h"
#include <qaction.h>
#include "qcommonstyle.h"
#include <qcombobox.h>
#include <qmovie.h>
#include "qtableview.h"
#include "qbutton.h"
#include <qnetwork.h>
#include "qurlinfo.h"
#include "qabstractlayout.h"
#include <qaccel.h>
#include "qmetaobject.h"
#include <qobjectlist.h>
#include <qbitmap.h>
#include <qpaintdevicemetrics.h>
#include "qdrawutil.h"
#include <qmotifstyle.h>
#include <qinputdialog.h>
#include <qpicture.h>
#include <qheader.h>
#include <qpixmapcache.h>
#include "qwindowsstyle.h"
#include <qpngio.h>
#include <qvariant.h>
#include <qobjectdict.h>
#include <qpolygonscanner.h>
#include <qmenubar.h>
#include <qprintdialog.h>
#include <qprinter.h>
#include "qprogressbar.h"
#include "qpushbutton.h"
#include "qscrollbar.h"
#include "qsemimodal.h"
#include "qdir.h"
#include <qradiobutton.h>
#include <qdial.h>
#include <qscrollview.h>
#include <qplatinumstyle.h>
#include <qwidgetlist.h>
#include <qrtlcodec.h>
#include <qcanvas.h>
#include <qdragobject.h>
#include <qprogressdialog.h>
#include <qsessionmanager.h>
#include <qsgistyle.h>
#include <qasciicache.h>
#include "qsignal.h"
#include <qsignalmapper.h>
#include <qsignalslotimp.h>
#include <qsimplerichtext.h>
#include "qlistbox.h"
#include <qsizegrip.h>
#include <qlayout.h>
#include <qsjiscodec.h>
#include <qslider.h>
#include <qsmartptr.h>
#include <qsocketnotifier.h>
#include <qsortedlist.h>
#include <qsound.h>
#include <qspinbox.h>
#include <qsplitter.h>
#include <qstack.h>
#include <qstatusbar.h>
#include <qasyncio.h>
#include <qiconview.h>
#include <qasyncimageio.h>
#include <qvector.h>
#include <qcdestyle.h>
#include <qstylesheet.h>
#include <qtabbar.h>
#include <qtabdialog.h>
#include <qtable.h>
#include <qmultilineedit.h>
#include <qtabwidget.h>
#include "qtextview.h"
#include <qbig5codec.h>
#include <qtextstream.h>
#include <qtextbrowser.h>
#include "qurl.h"
#include <qtl.h>
#include <qtoolbar.h>
#include <qtoolbutton.h>
#include <qtooltip.h>
#include <qapplication.h>
#include <qtsciicodec.h>
#include "qnetworkprotocol.h"
#include <qlocalfs.h>
#include "qlistview.h"
#include <qutfcodec.h>
#include <qvalidator.h>
#include <qclipboard.h>
#include <qvaluestack.h>
#include <qdom.h>
#include <qvbox.h>
#include <qvbuttongroup.h>
#include <qstrvec.h>
#include <qvgroupbox.h>
#include <qwhatsthis.h>
#include <qcheckbox.h>
#include <qwidgetintdict.h>
#include <qfocusdata.h>
#include <qwidgetstack.h>
#include <qmotifplusstyle.h>
#include <qcompactstyle.h>
#include <qwizard.h>
#include "qurloperator.h"
#include <qworkspace.h>
#include <qxml.h>
#include <qfiledialog.h>

#ifdef _WS_QWS_
#include "qhostaddress.h"
#include "qsocketdevice.h"
#include "qsocket.h"
#include <qserversocket.h>
#include <qftp.h>
#include <qdns.h>
#include <qfontmanager_qws.h>
#include <qfontfactorybdf_qws.h>
#include <qgfxvoodoodefs_qws.h>
#include <qfontfactoryttf_qws.h>
#include <qlock_qws.h>
#include "qmemorymanager_qws.h"
#include "qgfx_qws.h"
#include "qwsdisplay_qws.h"
#include <qwssocket_qws.h>
#include "qwsutils_qws.h"
#include <qwscursor_qws.h>
#include <qgfxraster_qws.h>
#include <qgfxvnc_qws.h>
#include "qwscommand_qws.h"
#include <qwsmanager_qws.h>
#include <qwsmouse_qws.h>
#include "qwsproperty_qws.h"
#include <qwsregionmanager_qws.h>
#include "qwsevent_qws.h"
#include <qwindowsystem_qws.h>
#endif // _WS_QWS_

#endif // QT_H

==> qt2-3.2p0.tgz: include/X11/qt2/qt.h <==
/****************************************************************************
**
** Qt GUI Toolkit
**
** This header file efficiently includes all Qt GUI Toolkit functionality.
**
** Generated : Tue Feb 13 13:38:03 EST 2001

**
** Copyright (C) 1995-2000 Trolltech AS.  All rights reserved.
**
** This file is part of the Qt GUI Toolkit.
**
*****************************************************************************/

#ifndef QT_H
#define QT_H
#include "qmodules.h"
#ifdef QT_MODULE_TOOLS
#include "qglobal.h"
#endif // TOOLS
#include <qfeatures.h>
#include <stdio.h>
#ifdef QT_MODULE_TOOLS
#include "qshared.h"
#include "qcollection.h"
#include "qgarray.h"
#include "qarray.h"
#include "qcstring.h"
#include "qglist.h"
#include "qiodevice.h"
#include <qstring.h>
#include "qdatastream.h"
#include "qdatetime.h"
#include "qgdict.h"
#include <qfile.h>
#include "qjpunicode.h"
#include "qtextcodec.h"
#include "qfileinfo.h"
#include "qlist.h"
#include "qbitarray.h"
#include <qgbkcodec.h>
#include <qdict.h>
#include "qgcache.h"
#include <qasciicache.h>
#include <qcache.h>
#include "qgvector.h"
#include <qintcache.h>
#include "qintdict.h"
#include "qbuffer.h"
#include <qjiscodec.h>
#include <qeucjpcodec.h>
#include <qkoi8codec.h>
#include "qstrlist.h"
#include <qmap.h>
#include "qptrdict.h"
#include <qqueue.h>
#include "qregexp.h"
#include <qrtlcodec.h>
#include <qeuckrcodec.h>
#include <qsjiscodec.h>
#include <qsortedlist.h>
#include <qstack.h>
#include "qasciidict.h"
#include "qvaluelist.h"
#include "qdir.h"
#include "qvector.h"
#include <qbig5codec.h>
#include <qtextstream.h>
#include <qtl.h>
#include <qtsciicodec.h>
#include <qutfcodec.h>
#include <qstringlist.h>
#include <qvaluestack.h>
#include <qstrvec.h>
#endif // TOOLS
#ifdef QT_MODULE_KERNEL
#include "qobjectdefs.h"
#include "qnamespace.h"
#include "qwindowdefs.h"
#include "qcolor.h"
#include <qmime.h>
#include <qpoint.h>
#include "qbrush.h"
#include <qsize.h>
#include "qpalette.h"
#include <qrect.h>
#include "qpaintdevice.h"
#include <qfont.h>
#include <qpixmap.h>
#include <qpen.h>
#include <qdropsite.h>
#include "qregion.h"
#include "qfontinfo.h"
#include "qsizepolicy.h"
#include <qfontdatabase.h>
#include "qfontmetrics.h"
#include "qevent.h"
#include <qgif.h>
#include <qobject.h>
#include "qiconset.h"
#include <qimage.h>
#include <qkeycode.h>
#include "qcursor.h"
#include "qurlinfo.h"
#include "qconnection.h"
#include "qguardedptr.h"
#include <qmovie.h>
#include <qasyncimageio.h>
#include "qnetworkprotocol.h"
#include "qstyle.h"
#include <qaccel.h>
#include "qmetaobject.h"
#include <qobjectlist.h>
#include <qbitmap.h>
#include <qpaintdevicemetrics.h>
#include "qpointarray.h"
#include "qtranslator.h"
#include <qwidget.h>
#include <qpicture.h>
#include <qdragobject.h>
#include <qpixmapcache.h>
#include <qpngio.h>
#include "qabstractlayout.h"
#include <qobjectdict.h>
#include <qpolygonscanner.h>
#include <qprinter.h>
#include "qwmatrix.h"
#include <qclipboard.h>
#include "qsemimodal.h"
#include <qsessionmanager.h>
#include "qtimer.h"
#include <qsignalmapper.h>
#include <qsignalslotimp.h>
#include <qsimplerichtext.h>
#include "qpainter.h"
#include <qsizegrip.h>
#include <qlayout.h>
#include "qsocketnotifier.h"
#include <qsound.h>
#include <qwidgetlist.h>
#include <qstylesheet.h>
#include <qthread.h>
#include "qsignal.h"
#include "qapplication.h"
#include "qurl.h"
#include <qlocalfs.h>
#include "qurloperator.h"
#include <qvariant.h>
#include <qvfbhdr.h>
#include "qdialog.h"
#include <qwidgetintdict.h>
#include <qfocusdata.h>
#include <qasyncio.h>
#include "qdrawutil.h"
#endif // KERNEL
#ifdef QT_MODULE_WIDGETS
#include <qaction.h>
#include "qbutton.h"
#include "qframe.h"
#include "qcommonstyle.h"
#include <qcheckbox.h>
#include <qcombobox.h>
#include "qmotifstyle.h"
#include "qwindowsstyle.h"
#include "qrangecontrol.h"
#include "qgroupbox.h"
#include <qgrid.h>
#include "qbuttongroup.h"
#include "qhbox.h"
#include <qhbuttongroup.h>
#include <qheader.h>
#include <qhgroupbox.h>
#include <qinterlacestyle.h>
#include "qlabel.h"
#include <qlcdnumber.h>
#include <qlineedit.h>
#include "qscrollbar.h"
#include "qscrollview.h"
#include "qmainwindow.h"
#include "qmenudata.h"
#include "qpopupmenu.h"
#include <qmotifplusstyle.h>
#include <qcdestyle.h>
#include "qtableview.h"
#include <qplatinumstyle.h>
#include <qmenubar.h>
#include "qprogressbar.h"
#include "qpushbutton.h"
#include <qradiobutton.h>
#include <qdial.h>
#include "qlistview.h"
#include "qlistbox.h"
#include <qsgistyle.h>
#include <qslider.h>
#include <qspinbox.h>
#include <qsplitter.h>
#include <qstatusbar.h>
#include <qtabbar.h>
#include <qmultilineedit.h>
#include <qtabwidget.h>
#include "qtextview.h"
#include <qtextbrowser.h>
#include <qtoolbar.h>
#include <qtoolbutton.h>
#include <qtooltip.h>
#include <qvalidator.h>
#include <qvbox.h>
#include <qvbuttongroup.h>
#include <qvgroupbox.h>
#include <qwhatsthis.h>
#include <qwidgetstack.h>

#endif // WIDGETS
#ifdef QT_MODULE_DIALOGS
#include <qcolordialog.h>
#include <qfiledialog.h>
#include <qfontdialog.h>
#include <qinputdialog.h>
#include <qmessagebox.h>
#include <qprintdialog.h>
#include <qprogressdialog.h>
#include <qtabdialog.h>
#include <qwizard.h>
#endif // DIALOGS
#ifdef QT_MODULE_CANVAS
#include <qcanvas.h>
#endif // CANVAS
#ifdef QT_MODULE_ICONVIEW
#include <qiconview.h>
#endif // ICONVIEW
#ifdef QT_MODULE_NETWORK
#include "qhostaddress.h"
#include "qsocketdevice.h"
#include "qsocket.h"
#include <qnetwork.h>
#include <qserversocket.h>
#include <qdns.h>
#include <qftp.h>
#endif // NETWORK
#ifdef QT_MODULE_TABLE
#include <qtable.h>
#endif // TABLE
#ifdef QT_MODULE_WORKSPACE
#include <qworkspace.h>
#endif // WORKSPACE
#ifdef QT_MODULE_XML
#include <qdom.h>
#include <qxml.h>
#endif // XML

#if defined( QT_MOC_CPP ) || defined( QT_H_CPP )
#ifdef QT_MODULE_KERNEL
#include "../kernel/qlayoutengine_p.h"
#include "../kernel/qpsprinter_p.h"
#include "../kernel/qrichtext_p.h"
#endif // KERNEL
#ifdef QT_MODULE_WIDGETS
#include "../widgets/qeffects_p.h"
#endif // WIDGETS
#endif // Private headers


#ifdef _WS_QWS_
#include "qwsdisplay_qws.h"
#ifdef QT_MODULE_KERNEL
#include <qfontmanager_qws.h>
#include <qfontfactoryttf_qws.h>
#include <qfontfactorybdf_qws.h>
#include <qgfxmatroxdefs_qws.h>
#include <qgfxvoodoodefs_qws.h>
#include "qmemorymanager_qws.h"
#include "qkeyboard_qws.h"
#include <qlock_qws.h>
#include <qcopchannel_qws.h>
#include <qdirectpainter_qws.h>
#include "qgfx_qws.h"
#include <qsoundqss_qws.h>
#include <qgfxraster_qws.h>
#include "qwsdecoration_qws.h"
#include <qwssocket_qws.h>
#include <qwscursor_qws.h>
#include "qwsmanager_qws.h"
#include "qwsdefaultdecoration_qws.h"
#include "qwsutils_qws.h"
#include <qwshydrodecoration_qws.h>
#include <qwskde2decoration_qws.h>
#include <qwskdedecoration_qws.h>
#include <qwsbeosdecoration_qws.h>
#include <qwsmouse_qws.h>
#include "qwscommand_qws.h"
#include <qwsregionmanager_qws.h>
#include "qwsevent_qws.h"
#include "qwsproperty_qws.h"
#include <qwswindowsdecoration_qws.h>
#include <qgfxvnc_qws.h>
#include <qwindowsystem_qws.h>
#endif // KERNEL
#endif // _WS_QWS_

#endif // QT_H
